@@ -30,6 +30,8 @@ var LibraryPThreadStub = {
   pthread_mutex_init: function() {},
   pthread_mutex_destroy: function() {},
   pthread_mutexattr_init: function() {},
+  pthread_mutexattr_setschedparam: function() {},
+  pthread_mutexattr_setprotocol: function() {},
   pthread_mutexattr_settype: function() {},
   pthread_mutexattr_destroy: function() {},
 
@@ -185,16 +187,24 @@ var LibraryPThreadStub = {
   pthread_spin_unlock: function() { return 0; },
 
   pthread_attr_setdetachstate: function() {},
+  pthread_att_setstacksize: function() {},
 
   pthread_create: function() {
     return {{{ cDefine('EAGAIN') }}};
   },
+  pthread_cancel: function() {},
   pthread_exit: function() {},
 
   pthread_equal: function() {},
   pthread_join: function() {},
   pthread_detach: function() {},
 
+  sem_init: function() {},
+  sem_post: function() {},
+  sem_wait: function() {},
+  sem_trywait: function() {},
+  sem_destroy: function() {},
+
   // When pthreads is not enabled, we can't use the Atomics futex api to do proper sleeps, so simulate a busy spin wait loop instead.
   usleep: function(useconds) {
     // int usleep(useconds_t useconds);
@@ -215,6 +225,18 @@ var LibraryPThreadStub = {
     return 0;
   },
 
+  nanosleep__deps: ['usleep'],
+  nanosleep: function(rqtp, rmtp) {
+    // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
+    var seconds = {{{ makeGetValue('rqtp', C_STRUCTS.timespec.tv_sec, 'i32') }}};
+    var nanoseconds = {{{ makeGetValue('rqtp', C_STRUCTS.timespec.tv_nsec, 'i32') }}};
+    if (rmtp !== 0) {
+      {{{ makeSetValue('rmtp', C_STRUCTS.timespec.tv_sec, '0', 'i32') }}};
+      {{{ makeSetValue('rmtp', C_STRUCTS.timespec.tv_nsec, '0', 'i32') }}};
+    }
+    return _usleep((seconds * 1e6) + (nanoseconds / 1000));
+  },
+
   llvm_memory_barrier: function(){},
 
   llvm_atomic_load_add_i32_p0i32: function(ptr, delta) {
