@@ -651,23 +651,16 @@ def get_clang_native_env():
       CACHED_CLANG_NATIVE_ENV = env
       return env
 
-    if 'VSINSTALLDIR' in env:
-      visual_studio_path = env['VSINSTALLDIR']
-    elif 'VS120COMNTOOLS' in env:
-      visual_studio_path = os.path.normpath(os.path.join(env['VS120COMNTOOLS'], '../..'))
-    elif 'VS140COMNTOOLS' in env:
-      visual_studio_path = os.path.normpath(os.path.join(env['VS140COMNTOOLS'], '../..'))
-    elif 'ProgramFiles(x86)' in env:
-      visual_studio_path = os.path.normpath(os.path.join(env['ProgramFiles(x86)'], 'Microsoft Visual Studio 12.0'))
-    elif 'ProgramFiles' in env:
-      visual_studio_path = os.path.normpath(os.path.join(env['ProgramFiles'], 'Microsoft Visual Studio 12.0'))
-    else:
-      visual_studio_path = 'C:\\Program Files (x86)\\Microsoft Visual Studio 12.0'
+    # Guess where VS2015 is installed (VSINSTALLDIR env. var in VS2015 X64 Command Prompt)
+    if 'VSINSTALLDIR' in env: visual_studio_path = env['VSINSTALLDIR']
+    elif 'VS140COMNTOOLS' in env: visual_studio_path = os.path.normpath(os.path.join(env['VS140COMNTOOLS'], '../..'))
+    elif 'ProgramFiles(x86)' in env: visual_studio_path = os.path.normpath(os.path.join(env['ProgramFiles(x86)'], 'Microsoft Visual Studio 14.0'))
+    elif 'ProgramFiles' in env: visual_studio_path = os.path.normpath(os.path.join(env['ProgramFiles'], 'Microsoft Visual Studio 14.0'))
+    else: visual_studio_path = 'C:\\Program Files (x86)\\Microsoft Visual Studio 14.0'
     if not os.path.isdir(visual_studio_path):
-      raise Exception('Visual Studio 2013 was not found in "' + visual_studio_path + '"! Run in Visual Studio command prompt to avoid the need to autoguess this location (or set VSINSTALLDIR env var).')
-
-    env['INCLUDE'] = os.path.join(visual_studio_path, 'VC\\INCLUDE')
+      raise Exception('Visual Studio 2015 was not found in "' + visual_studio_path + '"! Run in Visual Studio X64 command prompt to avoid the need to autoguess this location (or set VSINSTALLDIR env var).')
 
+    # Guess where Program Files (x86) is located
     if 'ProgramFiles(x86)' in env: prog_files_x86 = env['ProgramFiles(x86)']
     elif 'ProgramFiles' in env: prog_files_x86 = env['ProgramFiles']
     elif os.path.isdir('C:\\Program Files (x86)'): prog_files_x86 = 'C:\\Program Files (x86)'
@@ -675,22 +668,49 @@ def get_clang_native_env():
     else:
       raise Exception('Unable to detect Program files directory for native Visual Studio build!')
 
+    # Guess where Windows 8.1 SDK is located
     if 'WindowsSdkDir' in env:
-      windows_sdk_dir = env['WindowsSdkDir']
-    elif os.path.isdir(os.path.join(prog_files_x86, 'Windows Kits', '10')):
-      windows_sdk_dir = os.path.join(prog_files_x86, 'Windows Kits', '10')
-      include_dir = os.path.join(windows_sdk_dir, 'Include')
-      include_dir = [os.path.join(include_dir,x) for x in os.listdir(include_dir) if os.path.isdir(os.path.join(include_dir, x))][0] + '\\ucrt'
-      env['INCLUDE'] = env['INCLUDE'] + ';' + include_dir
+      windows8_sdk_dir = env['WindowsSdkDir']
     elif os.path.isdir(os.path.join(prog_files_x86, 'Windows Kits', '8.1')):
-      windows_sdk_dir = os.path.join(prog_files_x86, 'Windows Kits', '8.1')
-    else:
-      windows_sdk_dir = 'C:\\Program Files (x86)\\Windows Kits\\8.1'
-    if not os.path.isdir(windows_sdk_dir):
-      raise Exception('Windows SDK was not found in "' + windows_sdk_dir + '"! Run in Visual Studio command prompt to avoid the need to autoguess this location (or set WindowsSdkDir env var).')
+      windows8_sdk_dir = os.path.join(prog_files_x86, 'Windows Kits', '8.1')
+    if not os.path.isdir(windows8_sdk_dir):
+      raise Exception('Windows 8.1 SDK was not found in "' + windows8_sdk_dir + '"! Run in Visual Studio command prompt to avoid the need to autoguess this location (or set WindowsSdkDir env var).')
 
-    env['LIB'] = os.path.join(visual_studio_path, 'VC\\LIB\\amd64') + ';' + os.path.join(windows_sdk_dir, 'lib\\winv6.3\\um\\x64')
-    env['PATH'] = env['PATH'] + ';' + os.path.join(visual_studio_path, 'VC\\BIN')
+    # Guess where Windows 10 SDK is located
+    if os.path.isdir(os.path.join(prog_files_x86, 'Windows Kits', '10')):
+      windows10_sdk_dir = os.path.join(prog_files_x86, 'Windows Kits', '10')
+    if not os.path.isdir(windows10_sdk_dir):
+      raise Exception('Windows 10 SDK was not found in "' + windows10_sdk_dir + '"! Run in Visual Studio command prompt to avoid the need to autoguess this location.')
+
+    if not 'VSINSTALLDIR' in env: env['VSINSTALLDIR'] = visual_studio_path
+    if not 'VCINSTALLDIR' in env: env['VCINSTALLDIR'] = os.path.join(visual_studio_path, 'VC')
+
+    windows10sdk_kits_include_dir = os.path.join(windows10_sdk_dir, 'Include')
+    windows10sdk_kit_version_name = [x for x in os.listdir(windows10sdk_kits_include_dir) if os.path.isdir(os.path.join(windows10sdk_kits_include_dir, x))][0] # e.g. "10.0.10150.0" or "10.0.10240.0"
+
+    def append_item(key, item):
+      if not key in env or len(env[key].strip()) == 0: env[key] = item
+      else: env[key] = env[key] + ';' + item
+
+    append_item('INCLUDE', os.path.join(env['VCINSTALLDIR'], 'INCLUDE'))
+    append_item('INCLUDE', os.path.join(env['VCINSTALLDIR'], 'ATLMFC', 'INCLUDE'))
+    append_item('INCLUDE', os.path.join(windows10_sdk_dir, 'include', windows10sdk_kit_version_name, 'ucrt'))
+#   append_item('INCLUDE', 'C:\\Program Files (x86)\\Windows Kits\\NETFXSDK\\4.6.1\\include\\um') # VS2015 X64 command prompt has this, but not needed for Emscripten
+    append_item('INCLUDE', os.path.join(env['VCINSTALLDIR'], 'ATLMFC', 'INCLUDE'))
+    append_item('INCLUDE', os.path.join(windows8_sdk_dir, 'include', 'shared'))
+    append_item('INCLUDE', os.path.join(windows8_sdk_dir, 'include', 'um'))
+    append_item('INCLUDE', os.path.join(windows8_sdk_dir, 'include', 'winrt'))
+    logging.debug('VS2015 native build INCLUDE: ' + env['INCLUDE'])
+
+    append_item('LIB', os.path.join(env['VCINSTALLDIR'], 'LIB', 'amd64'))
+    append_item('LIB', os.path.join(env['VCINSTALLDIR'], 'ATLMFC', 'LIB', 'amd64'))
+    append_item('LIB', os.path.join(windows10_sdk_dir, 'lib', windows10sdk_kit_version_name, 'ucrt', 'x64'))
+#   append_item('LIB', 'C:\\Program Files (x86)\\Windows Kits\\NETFXSDK\\4.6.1\\lib\\um\\x64') # VS2015 X64 command prompt has this, but not needed for Emscripten
+    append_item('LIB', os.path.join(windows8_sdk_dir, 'lib', 'winv6.3', 'um', 'x64'))
+    logging.debug('VS2015 native build LIB: ' + env['LIB'])
+
+    env['PATH'] = env['PATH'] + ';' + os.path.join(env['VCINSTALLDIR'], 'BIN')
+    logging.debug('VS2015 native build PATH: ' + env['PATH'])
 
   # Current configuration above is all Visual Studio -specific, so on non-Windowses, no action needed.
 
@@ -862,8 +882,9 @@ def check_vanilla():
       is_vanilla_file = temp_cache.get('is_vanilla', get_vanilla_file, extension='.txt', force=True)
     try:
       contents = open(is_vanilla_file).read()
-      is_vanilla, llvm_used = contents.split(':')
-      is_vanilla = int(is_vanilla)
+      middle = contents.index(':')
+      is_vanilla = int(contents[:middle])
+      llvm_used = contents[middle + 1:]
       if llvm_used != LLVM_ROOT:
         logging.debug('regenerating vanilla check since other llvm')
         temp_cache.get('is_vanilla', get_vanilla_file, extension='.txt', force=True)
